# remirepo spec file for php-pecl-protobuf
#
# Copyright (c) 2016-2022 Remi Collet
# License: CC-BY-SA
# http://creativecommons.org/licenses/by-sa/4.0/
#
# Please, preserve the changelog entries
#

# we don't want -z defs linker flag
%undefine _strict_symbol_defs_build

%{?scl:%scl_package php-pecl-protobuf}

%global pecl_name   protobuf
%global with_zts    0
%global ini_name    40-%{pecl_name}.ini
%global upstream_version 3.21.11
#global upstream_prever  RC2

Summary:       Mechanism for serializing structured data
Name:          %{?scl_prefix}php-pecl-%{pecl_name}
Version:       %{upstream_version}%{?upstream_prever:~%{upstream_prever}}
Release:       1%{?dist}%{!?scl:%{!?nophptag:%(%{__php} -r 'echo ".".PHP_MAJOR_VERSION.".".PHP_MINOR_VERSION;')}}
# protobuf extension is BSD
# third_party/utf8_range is MIT
License:       BSD-3-Clause and MIT
URL:           https://pecl.php.net/package/%{pecl_name}
Source0:       https://pecl.php.net/get/%{pecl_name}-%{upstream_version}%{?upstream_prever}.tgz

BuildRequires: make
BuildRequires: %{?dtsprefix}gcc
BuildRequires: %{?scl_prefix}php-devel >= 7.0
BuildRequires: %{?scl_prefix}php-pear

Requires:      %{?scl_prefix}php(zend-abi) = %{php_zend_api}
Requires:      %{?scl_prefix}php(api) = %{php_core_api}
%{?_sclreq:Requires: %{?scl_prefix}runtime%{?_sclreq}%{?_isa}}

Provides:      %{?scl_prefix}php-%{pecl_name}               = %{version}
Provides:      %{?scl_prefix}php-%{pecl_name}%{?_isa}       = %{version}
Provides:      %{?scl_prefix}php-pecl(%{pecl_name})         = %{version}
Provides:      %{?scl_prefix}php-pecl(%{pecl_name})%{?_isa} = %{version}


%description
Google's language-neutral, platform-neutral, extensible mechanism for
serializing structured data.

See: https://developers.google.com/protocol-buffers/

Package built for PHP %(%{__php} -r 'echo PHP_MAJOR_VERSION.".".PHP_MINOR_VERSION;')%{?scl: as Software Collection (%{scl})}.


%prep
%setup -q -c 
mv %{pecl_name}-%{upstream_version}%{?upstream_prever} NTS

# Don't install/register tests
sed -e 's/role="test"/role="src"/' \
    -e '/utf8_range/s/role="doc"/role="src"/' \
    %{?_licensedir: -e '/LICENSE/s/role="doc"/role="src"/' } \
    %{!?_licensedir:-e '/LICENSE/s/role="src"/role="doc"/' } \
    -i package.xml

cd NTS
cp third_party/utf8_range/LICENSE LICENSE.utf8_range

# Sanity check, really often broken
extver=$(sed -n '/#define PHP_PROTOBUF_VERSION/{s/.* "//;s/".*$//;p}' protobuf.h)
if test "x${extver}" != "x%{upstream_version}%{?upstream_prever}"; then
   : Error: Upstream extension version is ${extver}, expecting %{upstream_version}%{?upstream_prever}.
   exit 1
fi
cd ..

%if %{with_zts}
# duplicate for ZTS build
cp -pr NTS ZTS
%endif

# Drop in the bit of configuration
cat > %{ini_name} << 'EOF'
; Enable %{pecl_name} extension module
extension = %{pecl_name}.so

; Configuration
;protobuf.keep_descriptor_pool_after_request = 0
EOF


%build
%{?dtsenable}

cd NTS
%{_bindir}/phpize
%configure \
    --enable-protobuf  \
    --with-php-config=%{_bindir}/php-config
make %{?_smp_mflags}

%if %{with_zts}
cd ../ZTS
%{_bindir}/zts-phpize
%configure \
    --enable-protobuf  \
    --with-php-config=%{_bindir}/zts-php-config
make %{?_smp_mflags}
%endif


%install
%{?dtsenable}

# Install the NTS stuff
make -C NTS install INSTALL_ROOT=%{buildroot}
install -D -m 644 %{ini_name} %{buildroot}%{php_inidir}/%{ini_name}

%if %{with_zts}
# Install the ZTS stuff
make -C ZTS install INSTALL_ROOT=%{buildroot}
install -D -m 644 %{ini_name} %{buildroot}%{php_ztsinidir}/%{ini_name}
%endif

# Install the package XML file
install -D -m 644 package.xml %{buildroot}%{pecl_xmldir}/%{name}.xml

# Test & Documentation
cd NTS
for i in $(grep 'role="test"' ../package.xml | sed -e 's/^.*name="//;s/".*$//')
do install -Dpm 644 $i %{buildroot}%{pecl_testdir}/%{pecl_name}/$i
done
for i in $(grep 'role="doc"' ../package.xml | sed -e 's/^.*name="//;s/".*$//')
do install -Dpm 644 $i %{buildroot}%{pecl_docdir}/%{pecl_name}/$i
done


%check
: Minimal load test for NTS extension
%{__php} --no-php-ini \
    --define extension=%{buildroot}%{php_extdir}/%{pecl_name}.so \
    --modules | grep %{pecl_name}

%if %{with_zts}
: Minimal load test for ZTS extension
%{__ztsphp} --no-php-ini \
    --define extension=%{buildroot}%{php_ztsextdir}/%{pecl_name}.so \
    --modules | grep %{pecl_name}

%endif


%if 0%{?fedora} < 24 && 0%{?rhel} < 8
# when pear installed alone, after us
%triggerin -- %{?scl_prefix}php-pear
if [ -x %{__pecl} ] ; then
    %{pecl_install} %{pecl_xmldir}/%{name}.xml >/dev/null || :
fi

# posttrans as pear can be installed after us
%posttrans
if [ -x %{__pecl} ] ; then
    %{pecl_install} %{pecl_xmldir}/%{name}.xml >/dev/null || :
fi

%postun
if [ $1 -eq 0 -a -x %{__pecl} ] ; then
    %{pecl_uninstall} %{pecl_name} >/dev/null || :
fi
%endif


%files
%{?_licensedir:%license NTS/LICENSE*}
%{!?_licensedir:%doc %{pecl_docdir}/%{pecl_name}}
%{pecl_xmldir}/%{name}.xml

%config(noreplace) %{php_inidir}/%{ini_name}
%{php_extdir}/%{pecl_name}.so

%if %{with_zts}
%config(noreplace) %{php_ztsinidir}/%{ini_name}
%{php_ztsextdir}/%{pecl_name}.so
%endif


%changelog
* Thu Dec  8 2022 Remi Collet <remi@remirepo.net> - 3.21.11-1
- update to 3.21.11

* Thu Dec  1 2022 Remi Collet <remi@remirepo.net> - 3.21.10-1
- update to 3.21.10

* Thu Oct 27 2022 Remi Collet <remi@remirepo.net> - 3.21.9-1
- update to 3.21.9 (no change)

* Wed Oct 19 2022 Remi Collet <remi@remirepo.net> - 3.21.8-1
- update to 3.21.8 (no change)

* Fri Sep 30 2022 Remi Collet <remi@remirepo.net> - 3.21.7-1
- update to 3.21.7 (no change)

* Wed Sep 14 2022 Remi Collet <remi@remirepo.net> - 3.21.6-1
- update to 3.21.6 (no change)

* Wed Aug 10 2022 Remi Collet <remi@remirepo.net> - 3.21.5-1
- update to 3.21.5

* Tue Jul 26 2022 Remi Collet <remi@remirepo.net> - 3.21.4-1
- update to 3.21.4 (no change)

* Fri Jul 22 2022 Remi Collet <remi@remirepo.net> - 3.21.3-1
- update to 3.21.3

* Mon Jun 27 2022 Remi Collet <remi@remirepo.net> - 3.21.2-1
- update to 3.21.2 (no change)

* Sat May 28 2022 Remi Collet <remi@remirepo.net> - 3.21.1-1
- update to 3.21.1 (no change)

* Thu May 26 2022 Remi Collet <remi@remirepo.net> - 3.21.0-1
- update to 3.21.0

* Mon May 23 2022 Remi Collet <remi@remirepo.net> - 3.21.0~RC2-1
- update to 3.21.0RC2

* Thu May 12 2022 Remi Collet <remi@remirepo.net> - 3.21.0~RC1-1
- update to 3.21.0RC1

* Mon Apr 25 2022 Remi Collet <remi@remirepo.net> - 3.20.1-1
- update to 3.20.1

* Thu Apr  7 2022 Remi Collet <remi@remirepo.net> - 3.20.1~RC1-1
- update to 3.20.1RC1

* Sun Apr  3 2022 Remi Collet <remi@remirepo.net> - 3.20.0-1
- update to 3.20.0
- add MIT License

* Mon Mar 21 2022 Remi Collet <remi@remirepo.net> - 3.20.0~RC2-1
- update to 3.20.0RC2

* Mon Mar  7 2022 Remi Collet <remi@remirepo.net> - 3.20.0~RC1-1
- update to 3.20.0RC1

* Mon Jan 31 2022 Remi Collet <remi@remirepo.net> - 3.19.4-1
- update to 3.19.4

* Wed Jan 12 2022 Remi Collet <remi@remirepo.net> - 3.19.3-1
- update to 3.19.3 (no change)

* Thu Jan  6 2022 Remi Collet <remi@remirepo.net> - 3.19.2-1
- update to 3.19.2 (no change)

* Fri Oct 29 2021 Remi Collet <remi@remirepo.net> - 3.19.1-1
- update to 3.19.1 (no change)

* Thu Oct 21 2021 Remi Collet <remi@remirepo.net> - 3.19.0-1
- update to 3.19.0

* Wed Oct 20 2021 Remi Collet <remi@remirepo.net> - 3.19.0~RC2-1
- update to 3.19.0RC2

* Mon Oct 18 2021 Remi Collet <remi@remirepo.net> - 3.19.0~RC1-1
- update to 3.19.0RC1

* Wed Oct  6 2021 Remi Collet <remi@remirepo.net> - 3.18.1-1
- update to 3.18.1

* Sat Sep 18 2021 Remi Collet <remi@remirepo.net> - 3.18.0-1
- update to 3.18.0

* Wed Sep 01 2021 Remi Collet <remi@remirepo.net> - 3.17.3-2
- rebuild for 8.1.0RC1

* Tue Jun  8 2021 Remi Collet <remi@remirepo.net> - 3.17.3-1
- update to 3.17.3
- add patch for PHP 8.1 from
  https://github.com/protocolbuffers/protobuf/pull/8710

* Thu Jun  3 2021 Remi Collet <remi@remirepo.net> - 3.17.2-1
- update to 3.17.2 (no change)

* Tue May 25 2021 Remi Collet <remi@remirepo.net> - 3.17.1-1
- update to 3.17.1

* Thu May 13 2021 Remi Collet <remi@remirepo.net> - 3.17.0-1
- update to 3.17.0 (no change)

* Wed May 12 2021 Remi Collet <remi@remirepo.net> - 3.17.0~RC2-1
- update to 3.17.0RC2 (no change)

* Fri May  7 2021 Remi Collet <remi@remirepo.net> - 3.16.0-1
- update to 3.16.0 (no change)

* Thu May  6 2021 Remi Collet <remi@remirepo.net> - 3.16.0~RC2-1
- update to 3.16.0RC2 (no change)

* Wed Apr  7 2021 Remi Collet <remi@remirepo.net> - 3.16.0~RC1-1
- update to 3.16.0RC1 (no change)

* Sat Apr  3 2021 Remi Collet <remi@remirepo.net> - 3.15.7-1
- update to 3.15.7 (no change)

* Fri Mar 12 2021 Remi Collet <remi@remirepo.net> - 3.15.6-1
- update to 3.15.6 (no change)

* Fri Mar  5 2021 Remi Collet <remi@remirepo.net> - 3.15.5-1
- update to 3.15.5

* Thu Mar  4 2021 Remi Collet <remi@remirepo.net> - 3.15.4-1
- update to 3.15.4

* Fri Feb 26 2021 Remi Collet <remi@remirepo.net> - 3.15.3-1
- update to 3.15.3 (no change)

* Wed Feb 24 2021 Remi Collet <remi@remirepo.net> - 3.15.2-1
- update to 3.15.2 (no change)

* Sat Feb 20 2021 Remi Collet <remi@remirepo.net> - 3.15.1-1
- update to 3.15.1 (no change)

* Fri Feb 19 2021 Remi Collet <remi@remirepo.net> - 3.15.0-1
- update to 3.15.0

* Wed Feb 10 2021 Remi Collet <remi@remirepo.net> - 3.15.0~RC1-1
- update to 3.15.0RC1

* Sat Nov 14 2020 Remi Collet <remi@remirepo.net> - 3.14.0-1
- update to 3.14.0

* Fri Nov 13 2020 Remi Collet <remi@remirepo.net> - 3.14.0~RC3-1
- update to 3.14.0RC3 (no change)

* Wed Nov 11 2020 Remi Collet <remi@remirepo.net> - 3.14.0~RC2-1
- update to 3.14.0RC2

* Mon Nov  9 2020 Remi Collet <remi@remirepo.net> - 3.14.0~RC1-1
- update to 3.14.0RC1
- open https://github.com/protocolbuffers/protobuf/issues/8016
  missing files in pecl package
- open https://github.com/protocolbuffers/protobuf/issues/8017
  bad version reported
- open https://github.com/protocolbuffers/protobuf/issues/8019
  strange changes

* Fri Oct  9 2020 Remi Collet <remi@remirepo.net> - 3.13.0.1-1
- update to 3.13.0.1

* Sat Aug 15 2020 Remi Collet <remi@remirepo.net> - 3.13.0-1
- update to 3.13.0
- raise dependency on PHP 7
- open https://github.com/protocolbuffers/protobuf/issues/7812

* Wed Jul 29 2020 Remi Collet <remi@remirepo.net> - 3.12.4-1
- update to 3.12.4 (no change)

* Thu Jul 16 2020 Remi Collet <remi@remirepo.net> - 3.12.3-1
- update to 3.12.3 (no change)

* Thu May 28 2020 Remi Collet <remi@remirepo.net> - 3.12.2-1
- update to 3.12.2 (no change)

* Thu May 21 2020 Remi Collet <remi@remirepo.net> - 3.12.1-1
- update to 3.12.1

* Mon May 18 2020 Remi Collet <remi@remirepo.net> - 3.12.0-1
- update to 3.12.0

* Wed May 13 2020 Remi Collet <remi@remirepo.net> - 3.12.0~RC2-1
- update to 3.12.0RC1

* Tue May  5 2020 Remi Collet <remi@remirepo.net> - 3.12.0~RC1-1
- update to 3.12.0RC1

* Sat Feb 15 2020 Remi Collet <remi@remirepo.net> - 3.11.4-1
- update to 3.11.4

* Tue Feb  4 2020 Remi Collet <remi@remirepo.net> - 3.11.3-1
- update to 3.11.3

* Sat Dec 14 2019 Remi Collet <remi@remirepo.net> - 3.11.2-1
- update to 3.11.2

* Tue Dec  3 2019 Remi Collet <remi@remirepo.net> - 3.11.1-1
- update to 3.11.1
- add patches for PHP 7.4 from
  https://github.com/protocolbuffers/protobuf/pull/6968

* Tue Nov 26 2019 Remi Collet <remi@remirepo.net> - 3.11.0-1
- update to 3.11.0

* Sat Nov 23 2019 Remi Collet <remi@remirepo.net> - 3.11.0~RC2-1
- update to 3.11.0RC2

* Thu Nov 21 2019 Remi Collet <remi@remirepo.net> - 3.11.0~RC1-1
- update to 3.11.0RC1
  https://github.com/protocolbuffers/protobuf/issues/6918

* Fri Oct  4 2019 Remi Collet <remi@remirepo.net> - 3.10.0-1
- update to 3.10.0

* Fri Sep  6 2019 Remi Collet <remi@remirepo.net> - 3.10.0~RC1-1
- update to 3.10.0RC1
- see https://github.com/protocolbuffers/protobuf/issues/6624
  broken extension with 7.4.0RC1

* Wed Aug  7 2019 Remi Collet <remi@remirepo.net> - 3.9.1-1
- update to 3.9.1 (no change)

* Fri Jul 12 2019 Remi Collet <remi@remirepo.net> - 3.9.0-1
- update to 3.9.0

* Thu Jun 27 2019 Remi Collet <remi@remirepo.net> - 3.9.0~RC1-1
- update to 3.9.0RC1

* Wed May 29 2019 Remi Collet <remi@remirepo.net> - 3.8.0-1
- update to 3.8.0
- open https://github.com/protocolbuffers/protobuf/issues/6180
  PHP 7.4 support

* Tue May  7 2019 Remi Collet <remi@remirepo.net> - 3.8.0~RC1-1
- update to 3.8.0RC1
- open https://github.com/protocolbuffers/protobuf/issues/6108
  missing file in pecl archive

* Wed Mar 27 2019 Remi Collet <remi@remirepo.net> - 3.7.1-1
- update to 3.7.1

* Fri Mar  1 2019 Remi Collet <remi@remirepo.net> - 3.7.0-1
- update to 3.7.0 (GA)

* Tue Feb 26 2019 Remi Collet <remi@remirepo.net> - 3.7.0~RC3-1
- update to 3.7.0RC3

* Mon Feb  4 2019 Remi Collet <remi@remirepo.net> - 3.7.0~RC2-1
- update to 3.7.0RC2
- open https://github.com/protocolbuffers/protobuf/issues/5672
  please clarify stability state

* Sat Aug 11 2018 Remi Collet <remi@remirepo.net> - 3.6.1-1
- update to 3.6.1
- drop patch merged upstream

* Wed Jul 18 2018 Remi Collet <remi@remirepo.net> - 3.6.0-3
- rebuild for 7.3.0alpha4 new ABI

* Fri Jul  6 2018 Remi Collet <remi@remirepo.net> - 3.6.0-2
- add patch for PHP 7.3 from
  https://github.com/google/protobuf/pull/4873

* Thu Jun  7 2018 Remi Collet <remi@remirepo.net> - 3.6.0-1
- update to 3.6.0

* Mon Jan  8 2018 Remi Collet <remi@remirepo.net> - 3.5.1.1-1
- Update to 3.5.1.1

* Thu Dec 21 2017 Remi Collet <remi@remirepo.net> - 3.5.1-1
- Update to 3.5.1

* Thu Dec 14 2017 Remi Collet <remi@remirepo.net> - 3.5.0.1-1
- add upstream patch to drop timelib_update_ts need

* Thu Dec  7 2017 Remi Collet <remi@remirepo.net> - 3.5.0.1-1
- Update to 3.5.0.1 (still broken)

* Tue Nov 21 2017 Remi Collet <remi@remirepo.net> - 3.5.0-1
- Update to 3.5.0
- open https://github.com/google/protobuf/issues/3929
  undefined symbol timelib_update_ts

* Thu Aug 17 2017 Remi Collet <remi@remirepo.net> - 3.4.0-1
- Update to 3.4.0

* Tue Jul 18 2017 Remi Collet <remi@remirepo.net> - 3.3.2-2
- rebuild for PHP 7.2.0beta1 new API

* Fri Jun 23 2017 Remi Collet <remi@remirepo.net> - 3.3.2-1
- Update to 3.3.2

* Fri May  5 2017 Remi Collet <remi@fedoraproject.org> - 3.3.0-1
- update to 3.3.0
- open https://github.com/google/protobuf/issues/3058 - PHP 7.1

* Tue Sep 27 2016 Remi Collet <remi@fedoraproject.org> - 3.1.0-0.1.a1
- initial package, version 3.1.0a1 (alpha)
- open https://github.com/google/protobuf/issues/2185 - License
- open https://github.com/google/protobuf/issues/2185 - ZTS build
- open https://github.com/google/protobuf/issues/2185 - PHP 7

